"""配置信息模块"""

import os
from dotenv import load_dotenv


if "RUNNER_TEMP" in os.environ:
    load_dotenv()
else:
    load_dotenv(".env", override=True)
    print("Load .env...")

OSS_ACCESS_KEY_ID = os.getenv("OSS_ACCESS_KEY_ID", None)
OSS_ACCESS_KEY_SECRET = os.getenv("OSS_ACCESS_KEY_SECRET", None)
OSS_ENDPOINT = os.getenv("OSS_ENDPOINT", None)
OSS_BUCKET_NAME = os.getenv("OSS_BUCKET_NAME", None)

if not OSS_ACCESS_KEY_ID or not OSS_ACCESS_KEY_SECRET or not OSS_ENDPOINT or not OSS_BUCKET_NAME:
    raise ValueError(f"The cloud storage parameters have not been set. Please set them and then try again.")



"""处理器基类"""

from abc import ABC, abstractmethod


class BaseHandler(ABC):
    @abstractmethod
    def upload(self, object_name, file_path):
        """
        上传文件

        Args:
            object_name: 云存储中的对象名称
            file_path: 本地文件路径
        """
        pass

    @abstractmethod
    def download(self, object_name, file_path):
        """
        下载文件

        Args:
            object_name: 云存储中的对象名称
            file_path: 本地文件路径
        """
        pass

    @abstractmethod
    def delete(self, object_name):
        """
        删除文件

        Args:
            object_name: 云存储中的对象名称
        """
        pass


"""命令行主模块"""

import typer
from pathlib import Path
from rich.console import Console
from ocsh.handlers.oss import OssHandler
from ocsh.config import OSS_ACCESS_KEY_ID, OSS_ACCESS_KEY_SECRET, OSS_ENDPOINT, OSS_BUCKET_NAME


app = typer.Typer(
    name = "Octopus Cloud Storage Hub",
    help = "Octopus Cloud Storage Hub CLI",
    rich_markup_mode="rich",
    add_completion = False
)

@app.command("upload")
def upload(
    object_name: str = typer.Argument(..., help="Cloud object name"),
    file_path: Path = typer.Argument(..., help="Local file path")
):
    """
    上传文件

    Args:
        object_name: 云存储对象名称
        file_path: 本地文件路径
    """
    pass

@app.command("download")
def download(
    object_name: str = typer.Argument(..., help="Cloud object name"),
    file_path: Path = typer.Argument(..., help="Local file path")
):
    """
    下载文件
    """
    pass

@app.command("delete")
def delete(object_name: str = typer.Argument(..., help="Cloud object name")):
    """
    删除云存储文件
    """
    pass

if __name__ == "__main__":
    app()



"""阿里云OSS处理器"""

import oss2
from ocsh.handlers.base_handler import BaseHandler


class OssHandler(BaseHandler):
    """
    阿里云OSS处理器
    """
    def __init__(self,access_key_id: str, access_key_secret: str, endpoint: str, bucket_name: str):
        self.auth = oss2.Auth(access_key_id, access_key_secret)
        self.bucket = oss2.Bucket(self.auth, endpoint, bucket_name)

    def upload(self, object_name, file_path):
        """
        上传到OSS
        """
        try:
            result = self.bucket.put_object_from_file(object_name, file_path)

        except Exception as e:
            print(f"文件上传失败：{e}")

    def download(self, object_name, file_path):
        """
        从OSS下载文件
        """
        try:
            result = self.bucket.get_object_to_file(object_name, file_path)
            if result.status == 200:
                print(f"{file_path}")
        except Exception as e:
            print(f"下载文件失败: {e}")

    def delete(self, object_name):
        """
        从OSS删除文件
        """
        try:
            result = self.bucket.delete_object(object_name)
            if result.status == 204:
                print("DONE")
        except Exception as e:
            print(f"删除文件失败: {e}")


"""命令行主模块"""

import json
import typer
from pathlib import Path

from ocsh.handlers.oss import OssHandler
from ocsh.config import OSS_ACCESS_KEY_ID, OSS_ACCESS_KEY_SECRET, OSS_ENDPOINT, OSS_BUCKET_NAME


app = typer.Typer(
    name = "octopus_cloud_storage_hub",
    help = "Octopus Cloud Storage Hub CLI",
    add_completion = False
)

oss_handler = OssHandler(
    access_key_id = OSS_ACCESS_KEY_ID,
    access_key_secret = OSS_ACCESS_KEY_SECRET,
    endpoint = OSS_ENDPOINT,
    bucket_name = OSS_BUCKET_NAME
)

@app.command("upload")
def upload(
    object_name: str = typer.Argument(..., help="Cloud object name"),
    file_path: Path = typer.Argument(..., help="Local file path")
):
    """
    上传文件
    """
    result = oss_handler.upload(object_name, file_path)
    print(json.dumps(result, indent=4))
    return result

@app.command("download")
def download(
    object_name: str = typer.Argument(..., help="Cloud object name"),
    file_path: Path = typer.Argument(..., help="Local file path")
):
    """
    下载文件
    """
    oss_handler.download(object_name, file_path)

@app.command("delete")
def delete(object_name: str = typer.Argument(..., help="Cloud object name")):
    """
    删除云存储文件
    """
    oss_handler.delete(object_name)

if __name__ == "__main__":
    app()



import os
import shutil
import subprocess
import sys

def clean_dist():
    """删除 dist 目录中的旧分发包"""
    dist_dir = os.path.join(os.getcwd(), "dist")
    if os.path.exists(dist_dir):
        print("正在删除旧的分发包...")
        shutil.rmtree(dist_dir)
    else:
        print("dist 目录不存在，无需清理。")

def build_package():
    """构建新的分发包"""
    print("正在构建新的分发包...")
    subprocess.run([sys.executable, "-m", "build"], check=True)

def upload_package():
    """上传分发包到 PyPI"""
    print("正在上传分发包到 PyPI...")
    subprocess.run(["twine", "upload", "dist/*"], check=True)

if __name__ == "__main__":
    clean_dist()
    build_package()
    upload_package()